@@ -28,16 +28,16 @@ unlink "./test.sdb";
 
 # 2: MAKE A TEST DATABASE.
 
-if ($^O =~ /Win/i)
-{
+#if ($^O =~ /Win/i)
+#{
 	system ("perl makesdb.pl test test test \".\" \".stb\" \"\\r\\n\" \",\"") ? 
 			print "not ok 2 ($@$?)\n" : print "ok 2\n";
-}
-else
-{
-	system ("./makesdb.pl test test test \".\" \".stb\" \"\\r\\n\" \",\"") ? 
-			print "not ok 2 ($@$?)\n" : print "ok 2\n";
-}
+#}
+#else
+#{
+#	system ("./makesdb.pl test test test \".\" \".stb\" \"\\r\\n\" \",\"") ? 
+#			print "not ok 2 ($@$?)\n" : print "ok 2\n";
+#}
 		
 # 3: FETCH LIST OF DATABASES (SHOULD JUST BE ONE - OUR NEW TEST ONE)!
 
